@@ -425,9 +425,13 @@ class SubscribeOptions(object):
         'details',
         'details_arg',
         'get_retained',
+        'correlation_id',
+        'correlation_uri',
+        'correlation_is_anchor',
     )
 
-    def __init__(self, match=None, details=None, details_arg=None, get_retained=None):
+    def __init__(self, match=None, details=None, details_arg=None, get_retained=None,
+                 correlation_id=None, correlation_uri=None, correlation_is_anchor=None):
         """
 
         :param match: The topic matching method to be used for the subscription.
@@ -460,6 +464,10 @@ class SubscribeOptions(object):
 
         self.get_retained = get_retained
 
+        self.correlation_id = correlation_id
+        self.correlation_uri = correlation_uri
+        self.correlation_is_anchor = correlation_is_anchor
+
     def message_attr(self):
         """
         Returns options dict as sent within WAMP messages.
@@ -567,6 +575,9 @@ class PublishOptions(object):
         'eligible_authid',
         'eligible_authrole',
         'retain',
+        'correlation_id',
+        'correlation_uri',
+        'correlation_is_anchor',
     )
 
     def __init__(self,
@@ -578,7 +589,10 @@ class PublishOptions(object):
                  eligible=None,
                  eligible_authid=None,
                  eligible_authrole=None,
-                 retain=None):
+                 retain=None,
+                 correlation_id=None,
+                 correlation_uri=None,
+                 correlation_is_anchor=None):
         """
 
         :param acknowledge: If ``True``, acknowledge the publication with a success or
@@ -630,6 +644,10 @@ class PublishOptions(object):
         self.eligible_authrole = eligible_authrole
         self.retain = retain
 
+        self.correlation_id = correlation_id
+        self.correlation_uri = correlation_uri
+        self.correlation_is_anchor = correlation_is_anchor
+
     def message_attr(self):
         """
         Returns options dict as sent within WAMP messages.
@@ -682,10 +700,13 @@ class RegisterOptions(object):
         'concurrency',
         'force_reregister',
         'details_arg',
+        'correlation_id',
+        'correlation_uri',
+        'correlation_is_anchor',
     )
 
-    def __init__(self, match=None, invoke=None, concurrency=None, details_arg=None,
-                 force_reregister=None):
+    def __init__(self, match=None, invoke=None, concurrency=None, details_arg=None, force_reregister=None,
+                 correlation_id=None, correlation_uri=None, correlation_is_anchor=None):
         """
 
         :param details_arg: When invoking the endpoint, provide call details
@@ -704,6 +725,10 @@ class RegisterOptions(object):
         self.details_arg = details_arg
         self.force_reregister = force_reregister
 
+        self.correlation_id = correlation_id
+        self.correlation_uri = correlation_uri
+        self.correlation_is_anchor = correlation_is_anchor
+
     def message_attr(self):
         """
         Returns options dict as sent within WAMP messages.
@@ -802,11 +827,17 @@ class CallOptions(object):
     __slots__ = (
         'on_progress',
         'timeout',
+        'correlation_id',
+        'correlation_uri',
+        'correlation_is_anchor',
     )
 
     def __init__(self,
                  on_progress=None,
-                 timeout=None):
+                 timeout=None,
+                 correlation_id=None,
+                 correlation_uri=None,
+                 correlation_is_anchor=None):
         """
 
         :param on_progress: A callback that will be called when the remote endpoint
@@ -822,6 +853,10 @@ class CallOptions(object):
         self.on_progress = on_progress
         self.timeout = timeout
 
+        self.correlation_id = correlation_id
+        self.correlation_uri = correlation_uri
+        self.correlation_is_anchor = correlation_is_anchor
+
     def message_attr(self):
         """
         Returns options dict as sent within WAMP messages.
